@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c,v 1.19 2002/04/03 01:38:28 kevinv Exp $ */
+/* $Id: gweather-dialog.c,v 1.24 2002/11/20 02:42:03 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -76,12 +76,16 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
 						  GTK_DIALOG_DESTROY_WITH_PARENT,
 						  GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 						  NULL);
+  gtk_dialog_set_default_response (GTK_DIALOG (gw_applet->gweather_dialog), 
+  				   GTK_RESPONSE_CLOSE);
 
   if (gw_applet->gweather_pref.radar_enabled)
-      gtk_widget_set_usize (gw_applet->gweather_dialog, 570, 440);
+      gtk_window_set_default_size (GTK_WINDOW(gw_applet->gweather_dialog), 570,440);
   else
-      gtk_widget_set_usize (gw_applet->gweather_dialog, 590, 340);
+      gtk_window_set_default_size (GTK_WINDOW(gw_applet->gweather_dialog), 590, 340);
 
+  gtk_window_set_screen (GTK_WINDOW (gw_applet->gweather_dialog),
+			 gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
   gtk_window_set_policy (GTK_WINDOW (gw_applet->gweather_dialog), FALSE, FALSE, FALSE);
   
   weather_vbox = GTK_DIALOG (gw_applet->gweather_dialog)->vbox;
@@ -309,9 +313,6 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       gtk_container_set_border_width (GTK_CONTAINER (radar_vbox), 6);
 
 
-      /* PUSH */
-      gtk_widget_push_colormap (gdk_rgb_get_cmap ());
-
       ebox = gtk_event_box_new ();
       gtk_widget_show (ebox);
       gtk_box_pack_start (GTK_BOX (radar_vbox), ebox, FALSE, FALSE, 0);
@@ -321,10 +322,6 @@ void gweather_dialog_create (GWeatherApplet *gw_applet)
       gtk_widget_show (gw_applet->radar_image);
       gtk_container_add (GTK_CONTAINER (ebox), gw_applet->radar_image);
 
-      /* POP */
-      gtk_widget_pop_colormap ();
-
-
       radar_link_alignment = gtk_alignment_new (0.5, 0.5, 0, 0);
       gtk_widget_show (radar_link_alignment);
       gtk_box_pack_start (GTK_BOX (radar_vbox), radar_link_alignment, FALSE, FALSE, 0);
